==> fwbuilder-3.0.2.tar.gz: fwbuilder-3.0.2/src/gui/global.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2003 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: global.h 565 2008-10-04 14:34:24Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifndef __GLOBAL_DEFS_
#define __GLOBAL_DEFS_

#include "../../VERSION.h"
#include <string>

class  QApplication;
class  FWWindow;
class  FWBSettings;
class  listOfLibraries;

extern QApplication      *app;
extern FWWindow          *mw;
extern FWBSettings       *st;

extern std::string     appRootDir;
extern std::string     userDataDir;
extern std::string     respath;
extern std::string     localepath;
extern std::string     librespath;
extern std::string     sysfname;
extern std::string     tempfname;
extern std::string     argv0;
extern std::string     ee;
extern int             fwbdebug;
extern bool            registered;
extern bool            gui_experiment1;

#define SETTINGS_PATH_PREFIX  "/3.0"

#ifdef NDEBUG
#  undef NDEBUG
#  include <assert.h>
#  define NDEBUG
#else
#  include <assert.h>
#endif

#endif

==> fwbuilder-3.0.5.tar.gz: fwbuilder-3.0.5/src/gui/global.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2003 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: global.h 777 2009-03-07 03:47:30Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifndef __GLOBAL_DEFS_
#define __GLOBAL_DEFS_

#include "../../VERSION.h"
#include <string>

class  QApplication;
class  FWWindow;
class  FWBSettings;
class  listOfLibraries;

extern QApplication      *app;
extern FWWindow          *mw;
extern FWBSettings       *st;

extern std::string     appRootDir;
extern std::string     userDataDir;
extern std::string     respath;
extern std::string     localepath;
extern std::string     librespath;
extern std::string     sysfname;
extern std::string     tempfname;
extern std::string     argv0;
extern std::string     ee;
extern int             fwbdebug;
extern int             registered;
extern bool            gui_experiment1;

#define SETTINGS_PATH_PREFIX  "/3.0"

#ifdef NDEBUG
#  undef NDEBUG
#  include <assert.h>
#  define NDEBUG
#else
#  include <assert.h>
#endif

#endif
